@@ -25,10 +25,11 @@ class TaggableMixin:
         list["Tag"],
         # lambda self, _: (Tagged.entity == self.gid) & (Tagged.tag == Tag.id)
         # doing an .on with and & inside can lead to a cross join,
-        # for relationships with pivot tables a manual on query is prefered:
-        on=lambda entity, _tag: [
-            Tagged.on(Tagged.entity == entity.gid),
-            Tag.on((Tagged.tag == Tag.id)),
+        # for relationships with pivot tables a manual on query with aliases is prefered:
+        on=lambda entity, tag: [
+            tagged := Tagged.unique_alias(),
+            tagged.on(tagged.entity == entity.gid),
+            tag.on((tagged.tag == tag.id)),
         ],
     )
     # tags = relationship(list["Tag"], tagged)
@@ -186,7 +187,6 @@ def test_typedal_way():
         Empty.first_or_fail()
 
     # user through article: 1 - many
-
     all_articles = Article.join().collect().as_dict()
 
     assert all_articles[3]["final_editor"]["name"] == "Editor 1"
@@ -293,6 +293,12 @@ def test_typedal_way():
 
     assert len(role_writer.users) == 2
 
+    author1 = User.where(id=4).join().first()
+
+    assert (
+        len(author1.as_dict()["articles"]) == len(author1.__dict__["articles"]) == len(dict(author1)["articles"]) == 2
+    )
+
 
 def test_reprs():
     _setup_data()
@@ -620,3 +626,19 @@ def test_count_with_join():
 
     assert User.where(id=4).join("articles").count(User.id) == 1
     assert User.where(id=4).join("articles").count(Article.id) == 2
+
+
+def test_accessing_raw_data():
+    _setup_data()
+
+    user = User.where(id=4).join("articles").first()
+
+    # <User({"id": 4, "name": "Untagged Author", "roles": [], "gid": "967da807-eb13-46dc-a0f3-d5c04751edf4", "main_role": 2, "extra_roles": []}) + ['articles']>
+    assert user._row
+
+    # one row per user+article combination like how postgres returns it:
+    assert len(user._rows) == 2
+
+    assert {row.user.id for row in user._rows} == {4}
+
+    assert {row.articles.id for row in user._rows} == {1, 2}
